@@ -311,12 +311,14 @@ class PhotoExporter:
             )
         elif staged_files.update_skipped and _dest_exists(dest):
             all_results.skipped.append(str(dest))
+            all_results.uuids[str(dest)] = self.photo.uuid
             options.export_db.set_history(str(dest), self.photo.uuid, "skip", None)
         else:
             verbose(
                 f"Skipping missing {'edited' if options.edited else 'original'} photo {self._filename(self.photo.original_filename)} ({self._uuid(self.photo.uuid)})"
             )
             all_results.missing.append(dest)
+            all_results.uuids[str(dest)] = self.photo.uuid
 
         # copy live photo associated .mov if requested
         if export_original and options.live_photo and self.photo.live_photo:
@@ -391,6 +393,7 @@ class PhotoExporter:
                     verbose(
                         f"Skipping missing raw photo for {self._filename(self.photo.original_filename)} ({self._uuid(self.photo.uuid)})"
                     )
+                all_results.uuids[str(raw_name)] = self.photo.uuid
 
         # copy preview image if requested
         if options.preview:
@@ -419,6 +422,7 @@ class PhotoExporter:
                 # don't know what actual preview suffix would be but most likely jpeg
                 preview_name = dest.parent / f"{dest.stem}{options.preview_suffix}.jpeg"
                 all_results.missing.append(preview_name)
+                all_results.uuids[preview_name] = self.photo.uuid
                 verbose(
                     f"Skipping missing preview photo for {self._filename(self.photo.original_filename)} ({self._uuid(self.photo.uuid)})"
                 )
@@ -558,10 +562,6 @@ class PhotoExporter:
         if options.update or options.force_update:
             export_db = options.export_db
             dest_uuid = export_db.get_uuid_for_file(dest)
-            if dest_uuid is None and not _dest_exists(dest):
-                # destination doesn't exist in export db and doesn't exist on disk
-                # so we can just use it
-                return dest
 
             if dest_uuid == self.photo.uuid:
                 # destination is the right file
@@ -1096,6 +1096,7 @@ class PhotoExporter:
                 )
                 if exported:
                     results.raw = exported[0]
+                    results.uuids[exported[0]] = self.photo.uuid
             except Exception as e:
                 results.error.append((str(dest), f"{e} ({lineno(__file__)})"))
 
@@ -1384,6 +1385,14 @@ class PhotoExporter:
             updated=update_updated_files,
         )
 
+        for f in (
+            exported_files
+            + update_new_files
+            + update_updated_files
+            + update_skipped_files
+        ):
+            results.uuids[f] = self.photo.uuid
+
         # touch files if needed
         if options.touch_file:
             results += touch_files(
@@ -1688,6 +1697,7 @@ class PhotoExporter:
             new=new,
             updated=updated,
             error=errors,
+            uuids={str(dest): self.photo.uuid},
         )
 
     def write_exiftool_metadata_to_file(
