@@ -1,4 +1,4 @@
-""" Utility functions used in osxphotos """
+"""Utility functions used in osxphotos"""
 
 from __future__ import annotations
 
@@ -12,6 +12,7 @@ import os
 import os.path
 import pathlib
 import re
+import stat
 import subprocess
 import sys
 import urllib.parse
@@ -22,6 +23,9 @@ from plistlib import load as plistload
 from typing import TYPE_CHECKING, Callable, List, Optional, Tuple, TypeVar, Union
 from uuid import UUID
 
+if TYPE_CHECKING:
+    from .stat_cache import DirectoryStatCache
+
 import requests
 import shortuuid
 
@@ -40,19 +44,20 @@ logger = logging.getLogger("osxphotos")
 __all__ = [
     "dd_to_dms_str",
     "expand_and_validate_filepath",
+    "find_files_by_prefix",
     "get_last_library_path",
     "get_system_library_path",
     "hexdigest",
-    "increment_filename_with_count",
     "increment_filename",
+    "increment_filename_with_count",
     "lineno",
     "list_directory",
     "list_photo_libraries",
     "load_function",
-    "lock_filename",
     "noop",
     "pluralize",
     "shortuuid_to_uuid",
+    "terminal",
     "uuid_to_shortuuid",
 ]
 
@@ -223,7 +228,7 @@ def get_last_library_path() -> str | None:
                 urllib.parse.unquote(urllib.parse.urlparse(photosurlstr).path)
             )
         else:
-            logging.warning(
+            logger.warning(
                 "Could not extract photos URL String from IPXDefaultLibraryURLBookmark"
             )
             return None
@@ -348,7 +353,9 @@ def list_directory(
 
 
 def increment_filename_with_count(
-    filepath: Union[str, pathlib.Path], count: int = 0, lock: bool = False
+    filepath: Union[str, pathlib.Path],
+    count: int = 0,
+    stat_cache: Optional["DirectoryStatCache"] = None,
 ) -> Tuple[str, int]:
     """Return filename (1).ext, etc if filename.ext exists
 
@@ -358,7 +365,7 @@ def increment_filename_with_count(
     Args:
         filepath: str or pathlib.Path; full path, including file name
         count: int; starting increment value
-        lock: bool, if True, creates lock file to reserve filename
+        stat_cache: Optional DirectoryStatCache for efficient directory listing on network volumes
 
     Returns:
         tuple of new filepath (or same if not incremented), count
@@ -366,8 +373,16 @@ def increment_filename_with_count(
     Note: This obviously is subject to race condition so using with caution.
     """
     dest = filepath if isinstance(filepath, pathlib.Path) else pathlib.Path(filepath)
-    dest_files = list_directory(dest.parent, startswith=dest.stem)
-    dest_files = [f.stem.lower() for f in dest_files]
+
+    # Use stat cache for directory listing if available, otherwise fall back to list_directory
+    if stat_cache is not None:
+        dest_files = stat_cache.list_directory(dest.parent, startswith=dest.stem)
+        # list_directory from stat_cache returns just filenames, need to extract stems
+        dest_files = [pathlib.Path(f).stem.lower() for f in dest_files]
+    else:
+        dest_files = list_directory(dest.parent, startswith=dest.stem)
+        dest_files = [f.stem.lower() for f in dest_files]
+
     dest_new = f"{dest.stem} ({count})" if count else dest.stem
     dest_new = normalize_fs_path(dest_new)
 
@@ -375,13 +390,13 @@ def increment_filename_with_count(
         count += 1
         dest_new = normalize_fs_path(f"{dest.stem} ({count})")
     dest = dest.parent / f"{dest_new}{dest.suffix}"
-    if lock and not lock_filename(dest):
-        # if lock fails, increment count and try again
-        return increment_filename_with_count(filepath, count + 1, lock=lock)
     return normalize_fs_path(str(dest)), count
 
 
-def increment_filename(filepath: Union[str, pathlib.Path], lock: bool = False) -> str:
+def increment_filename(
+    filepath: Union[str, pathlib.Path],
+    stat_cache: Optional["DirectoryStatCache"] = None,
+) -> str:
     """Return filename (1).ext, etc if filename.ext exists
 
         If file exists in filename's parent folder with same stem as filename,
@@ -390,52 +405,19 @@ def increment_filename(filepath: Union[str, pathlib.Path], lock: bool = False) -
     Args:
         filepath: str or pathlib.Path; full path, including file name
         force: force the file count to increment by at least 1 even if filepath doesn't exist
-        lock: bool, if True, creates lock file to reserve filename
+        stat_cache: Optional DirectoryStatCache for efficient directory listing on network volumes
 
     Returns:
         new filepath (or same if not incremented)
 
     Note: This obviously is subject to race condition so using with caution.
     """
-    new_filepath, _ = increment_filename_with_count(filepath, lock=lock)
+    new_filepath, _ = increment_filename_with_count(
+        filepath, stat_cache=stat_cache
+    )
     return new_filepath
 
 
-def lock_filename(filepath: Union[str, pathlib.Path]) -> bool:
-    """Create empty lock file to reserve file.
-        Lock file will have name of filepath with .osxphotos.lock extension.
-
-    Args:
-        filepath: str or pathlib.Path; full path, including file name
-
-    Returns:
-        filepath if lock file created, False if lock file already exists
-    """
-    return filepath
-
-    # TODO: for future implementation
-    lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
-    if lockfile.exists():
-        return False
-    lockfile.touch()
-    return filepath
-
-
-def unlock_filename(filepath: Union[str, pathlib.Path]):
-    """Remove lock file created by lock_filename()
-
-    Args:
-        filepath: str or pathlib.Path; full path, including file name
-    """
-
-    return
-
-    # TODO: for future implementation
-    lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
-    if lockfile.exists():
-        lockfile.unlink()
-
-
 def extract_increment_count_from_filename(filepath: Union[str, pathlib.Path]) -> int:
     """Extract a count from end of file name if it exists or 0 if not; count takes forms file (1).ext, file (2).ext, etc."""
     filepath = str(filepath)
@@ -671,3 +653,63 @@ def terminal() -> str:
     Note: This only works on macOS
     """
     return os.environ.get("TERM_PROGRAM", "")
+
+
+def find_files_by_prefix(
+    filepath: str | os.PathLike,
+    start_str: str,
+    ignore_ext: str | None = None,
+    cache_results=True,
+) -> list[str]:
+    """
+    Find all files starting with start_str in directory filepath,
+    sorted by size (largest first).
+
+    Args:
+        filepath: Directory to search
+        start_str: Prefix to match (case sensitive)
+        ignore_ext: Optional extension to ignore (must include leading "."), e.g. ".tmp"
+        cache_results: Whether to cache the listdir results
+
+    Raises:
+        FileNotFoundError if filepath doesn't exist
+
+    Note:
+        This uses listdir vs scandir or glob as benchmarking shows this is the fastest way to find a small number
+        of files in a large directory.
+    """
+    if ignore_ext is not None:
+        ignore_ext = ignore_ext.lower()
+
+    matching_files = []
+
+    contents = _listdir_cache(filepath) if cache_results else os.listdir(filepath)
+    for name in contents:
+        if name.startswith(start_str):
+            if ignore_ext is not None:
+                _, ext = os.path.splitext(name)
+                if ext.lower() == ignore_ext:
+                    continue
+
+            full_path = os.path.join(filepath, name)
+            try:
+                st = os.stat(full_path)
+                if stat.S_ISREG(st.st_mode):  # is regular file
+                    matching_files.append((full_path, st.st_size))
+            except OSError:
+                continue
+
+    matching_files.sort(key=lambda x: x[1], reverse=True)
+    return [f for f, _ in matching_files]
+
+
+@cache
+def _listdir_cache(filepath: str | os.PathLike) -> list[str]:
+    """Cached listdir"""
+    return os.listdir(filepath)
+
+
+@cache
+def isdir_cache(path: str | os.PathLike) -> bool:
+    """Cached os.path.isdir"""
+    return os.path.isdir(str(path))
